pub struct Measurement<T, U: Unit> { /* private fields */ }Expand description
Type-safe measurement with units
Implementations
Sourceimpl<T, U: Unit> Measurement<T, U>
impl<T, U: Unit> Measurement<T, U>
Sourcepub unsafe fn convert_unit<V: Unit>(self) -> Measurement<T, V>
pub unsafe fn convert_unit<V: Unit>(self) -> Measurement<T, V>
Convert to different unit (unsafe, requires manual verification)
Safety
The caller must ensure that the conversion between units is mathematically valid and that the value makes sense in the target unit system.